# neural-commons

Neural network utilities and helpers for PyTorch.

## Installation

    pip install neural-commons

## Features and Utilities

- [Closed-Form Optimization](https://github.com/jose-solorzano/neural-commons/blob/main/doc/closed-form-optimization.md)
